@@ -2,6 +2,7 @@
  * This file is part of nzbget. See <https://nzbget.com>.
  *
  * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2024 Denis <denis@nzbget.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /*
@@ -47,6 +48,7 @@ var Downloads = (new function($)
 	var nameColumnWidth = null;
 	var cached = false;
 	var lastDownloadRate;
+	var listGroupsSubs = [];
 
 	var statusData = {
 		'QUEUED': { Text: 'QUEUED', PostProcess: false },
@@ -114,6 +116,7 @@ var Downloads = (new function($)
 
 		DownloadsActionsMenu.init();
 	}
+	
 
 	this.applyTheme = function()
 	{
@@ -127,6 +130,19 @@ var Downloads = (new function($)
 		RPC.call('listgroups', [], groups_loaded, null, { prefer_cached: true });
 	}
 
+	this.subscribe = function(sub)
+	{
+		listGroupsSubs.push(sub);
+	}
+
+	function notifyAll(data)
+	{
+		listGroupsSubs.forEach(function(sub)
+		{
+			sub.update(data);
+		});
+	}
+
 	function groups_loaded(_groups, _cached)
 	{
 		if (!groups)
@@ -141,6 +157,7 @@ var Downloads = (new function($)
 			Downloads.groups = groups;
 			prepare();
 		}
+		notifyAll(groups);
 		RPC.next();
 	}
 
@@ -627,8 +644,8 @@ var Downloads = (new function($)
 		var editIds = buildContextIdList(group);
 		$PriorityMenu.data('nzbids', editIds);
 		DownloadsUI.updateContextWarning($PriorityMenu, editIds);
-		$('i', $PriorityMenu).removeClass('icon-ok').addClass('icon-empty');
-		$('li[data=' + group.MaxPriority + '] i', $PriorityMenu).addClass('icon-ok');
+		$('i', $PriorityMenu).css('visibility','hidden');
+		$('li[data=' + group.MaxPriority + '] i', $PriorityMenu).css('visibility','visible');
 		Frontend.showPopupMenu($PriorityMenu, 'left',
 			{ left: $(this).offset().left - 30, top: $(this).offset().top,
 				width: $(this).width() + 30, height: $(this).outerHeight() - 2});
@@ -671,8 +688,8 @@ var Downloads = (new function($)
 		var editIds = buildContextIdList(group);
 		$CategoryMenu.data('nzbids', editIds);
 		DownloadsUI.updateContextWarning($CategoryMenu, editIds);
-		$('i', $CategoryMenu).removeClass('icon-ok').addClass('icon-empty');
-		$('li[data="' + group.Category + '"] i', $CategoryMenu).addClass('icon-ok');
+		$('i', $CategoryMenu).text('');
+		$('li[data="' + group.Category + '"] i', $CategoryMenu).text('done');
 
 		Frontend.showPopupMenu($CategoryMenu, 'left',
 			{ left: $(this).offset().left - 30, top: $(this).offset().top,
