@@ -2,6 +2,7 @@
  * This file is part of nzbget. See <https://nzbget.com>.
  *
  * Copyright (C) 2012-2017 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2024 Denis <denis@nzbget.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /*
@@ -157,6 +158,89 @@ var UISettings = (new function($)
 $(document).ready(function()
 {
 	Frontend.init();
+	var lightThemeStyleSheet = 'light-theme.css';
+	var darkThemeStyleSheet = 'dark-theme.css';
+	var themeToggleBtn = $('#ThemeToggle');
+	var themeStyleSheet = $('#ThemeStyleSheet');
+	var darkThemeToggleBtn = $('<i class="material-icon" title="Switch to dark theme">dark_mode</i>');
+	var lightThemeToggleBtn = $('<i class="material-icon" title="Switch to light theme">light_mode</i>');
+	var savedTheme = getSavedTheme();
+
+	if (!savedTheme)
+	{
+		turnOnThemeDependingOnSystemTheme();
+	}
+	else
+	{
+		if (savedTheme == 'light')
+		{
+			turnOnLightTheme();
+		}
+		else
+		{
+			turnOnDarkTheme();
+		}
+	}
+
+	subscribe();
+
+	function saveTheme(theme)
+	{
+		window.localStorage.setItem('Theme', theme);
+	}
+
+	function turnOnThemeDependingOnSystemTheme()
+	{
+		if (isSystemThemeDark()) 
+		{
+			turnOnDarkTheme();
+		} else 
+		{
+			turnOnLightTheme();
+		}
+	}
+
+	function turnOnLightTheme()
+	{
+		themeStyleSheet.attr('href', lightThemeStyleSheet);
+		themeToggleBtn.children().replaceWith(darkThemeToggleBtn);
+	}
+
+	function turnOnDarkTheme()
+	{
+		themeStyleSheet.attr('href', darkThemeStyleSheet);
+		themeToggleBtn.children().replaceWith(lightThemeToggleBtn);
+	}
+
+	function getSavedTheme()
+	{
+		return window.localStorage.getItem('Theme');
+	}
+
+	function isSystemThemeDark()
+	{
+		return window.matchMedia && window.matchMedia('(prefers-color-scheme: dark)').matches;
+	}
+
+	function isDarkTheme()
+	{
+		return themeStyleSheet.attr('href') === lightThemeStyleSheet;
+	}
+
+	function subscribe()
+	{
+		themeToggleBtn.on('click', function() {
+			if (isDarkTheme()) 
+			{
+				turnOnDarkTheme();
+				saveTheme('dark')
+			} else 
+			{
+				turnOnLightTheme();
+				saveTheme('light');
+			}
+		});
+	}
 });
 
 
@@ -194,7 +278,6 @@ var Frontend = (new function($)
 		switchTheme();
 		windowResized();
 
-		Options.init();
 		Status.init();
 		Downloads.init({ updateTabInfo: updateTabInfo });
 		Messages.init({ updateTabInfo: updateTabInfo });
@@ -212,6 +295,7 @@ var Frontend = (new function($)
 		ScriptListDialog.init();
 		RestoreSettingsDialog.init();
 		LimitDialog.init();
+		SystemInfo.init();
 
 		DownloadsEditDialog.init();
 		DownloadsMultiDialog.init();
@@ -751,6 +835,7 @@ var Refresher = (new function($)
 		RPC.safeMethods = [
 			'version', 
 			'status', 
+			'sysinfo',
 			'listgroups', 
 			'history', 
 			'listfiles',
@@ -766,7 +851,9 @@ var Refresher = (new function($)
 			'updateextension',
 			'deleteextension',
 			'readurl', 
-			'servervolumes'
+			'servervolumes',
+			'testserverspeed',
+			'testdiskspeed',
 		];
 
 		$('#RefreshMenu li a').click(refreshIntervalClick);
